# Federate Configuration

Federates have a number of options for configuration. This includes a number of timing options controlling how the federate advances in time and interacts with other federates
Other options to specify how the federate communicates with HELICS. There are also a variety of options for specifying the interfaces of a federate and the communication points by which a
federate interacts with others. This can be through file configurations (JSON) or through API calls.

```eval_rst
.. toctree::
  :maxdepth: 1

  Federate
  MessageFederate
  ValueFederate
  Filters
  Timing
  FederateInfo
  FederateFlags
  CoreTypes
```
